@@ -1,7 +1,7 @@
 
-##  RApiSerialize -- Packge to provide Serialization as in the R API 
+##  RApiSerialize -- Packge to provide Serialization as in the R API
 ##
-##  Copyright (C) 2014         Dirk Eddelbuettel 
+##  Copyright (C) 2014 - 2022  Dirk Eddelbuettel
 ##
 ##  This file is part of RApiSerialize.
 ##
@@ -18,10 +18,10 @@
 ##  You should have received a copy of the GNU General Public License
 ##  along with RApiSerialize.  If not, see <http://www.gnu.org/licenses/>.
 
-serializeToRaw <- function(obj) {
-    .Call("serializeToRaw", obj, PACKAGE="RApiSerialize")
+serializeToRaw <- function(obj, version=2) {
+    .Call(C_serializeToRaw, obj, version)
 }
 
 unserializeFromRaw <- function(obj) {
-    .Call("unserializeFromRaw", obj, PACKAGE="RApiSerialize")
+    .Call(C_unserializeFromRaw, obj)
 }
